HEAD class final
Represents an HTTP HEAD route.
Use HEAD when returning metadata headers for a resource without including the body.
Example
final router = RouterBuilder()
..head('/status', (req) => {});
This defines a HEAD route for /status.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → HttpMethod
-
The HTTP method (e.g., GET, POST) that this route responds to.
finalinherited
- path → String
-
The URI path associated with this route.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
equalizedProperties(
) → List< Object?> -
Mixin-style contract for value-based equality,
hashCode, andtoString.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited